import { useCallback, useEffect } from 'react';
export function useClickOutside(refs, callback = () => { }) {
    const handleClickOutside = useCallback((event) => {
        const clickedOutside = refs.every(ref => {
            return ref.current && !ref.current.contains(event.target);
        });
        callback(clickedOutside);
    }, [refs, callback]);
    useEffect(() => {
        document.addEventListener('click', handleClickOutside);
        return () => {
            document.removeEventListener('click', handleClickOutside);
        };
    }, [handleClickOutside]);
}
